"""seagrin.schemas package entry file.

This module provides the following classes:
- BaseResource
- Publisher
"""

__all__ = ["BaseResource", "Publisher"]

from seagrin.schemas._base import BaseResource
from seagrin.schemas.publisher import Publisher
